@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 icons = \
 ('glass',
  'music',
@@ -157,10 +158,12 @@ icons = \
  'phone-square',
  'twitter',
  'facebook',
+ 'facebook-f',
  'github',
  'unlock',
  'credit-card',
  'rss',
+ 'feed',
  'hdd-o',
  'bullhorn',
  'bell',
@@ -395,6 +398,7 @@ icons = \
  'trello',
  'female',
  'male',
+ 'gratipay',
  'gittip',
  'sun-o',
  'moon-o',
@@ -489,6 +493,8 @@ icons = \
  'git-square',
  'git',
  'hacker-news',
+ 'y-combinator-square',
+ 'yc-square',
  'tencent-weibo',
  'qq',
  'weixin',
@@ -547,4 +553,144 @@ icons = \
  'ils',
  'shekel',
  'sheqel',
- 'meanpath')
+ 'meanpath',
+ 'buysellads',
+ 'connectdevelop',
+ 'dashcube',
+ 'forumbee',
+ 'leanpub',
+ 'sellsy',
+ 'shirtsinbulk',
+ 'simplybuilt',
+ 'skyatlas',
+ 'cart-plus',
+ 'cart-arrow-down',
+ 'diamond',
+ 'ship',
+ 'user-secret',
+ 'motorcycle',
+ 'street-view',
+ 'heartbeat',
+ 'venus',
+ 'mars',
+ 'mercury',
+ 'transgender',
+ 'intersex',
+ 'transgender-alt',
+ 'venus-double',
+ 'mars-double',
+ 'venus-mars',
+ 'mars-stroke',
+ 'mars-stroke-v',
+ 'mars-stroke-h',
+ 'neuter',
+ 'genderless',
+ 'facebook-official',
+ 'pinterest-p',
+ 'whatsapp',
+ 'server',
+ 'user-plus',
+ 'user-times',
+ 'bed',
+ 'hotel',
+ 'viacoin',
+ 'train',
+ 'subway',
+ 'medium',
+ 'y-combinator',
+ 'yc',
+ 'optin-monster',
+ 'opencart',
+ 'expeditedssl',
+ 'battery-full',
+ 'battery-4',
+ 'battery-three-quarters',
+ 'battery-3',
+ 'battery-half',
+ 'battery-2',
+ 'battery-quarter',
+ 'battery-1',
+ 'battery-empty',
+ 'battery-0',
+ 'mouse-pointer',
+ 'i-cursor',
+ 'object-group',
+ 'object-ungroup',
+ 'sticky-note',
+ 'sticky-note-o',
+ 'cc-jcb',
+ 'cc-diners-club',
+ 'clone',
+ 'balance-scale',
+ 'hourglass-o',
+ 'hourglass-start',
+ 'hourglass-1',
+ 'hourglass-half',
+ 'hourglass-2',
+ 'hourglass-end',
+ 'hourglass-3',
+ 'hourglass',
+ 'hand-rock-o',
+ 'hand-grab-o',
+ 'hand-paper-o',
+ 'hand-stop-o',
+ 'hand-scissors-o',
+ 'hand-lizard-o',
+ 'hand-spock-o',
+ 'hand-pointer-o',
+ 'hand-peace-o',
+ 'trademark',
+ 'registered',
+ 'creative-commons',
+ 'gg',
+ 'gg-circle',
+ 'tripadvisor',
+ 'odnoklassniki',
+ 'odnoklassniki-square',
+ 'get-pocket',
+ 'wikipedia-w',
+ 'safari',
+ 'chrome',
+ 'firefox',
+ 'opera',
+ 'internet-explorer',
+ 'television',
+ 'tv',
+ 'contao',
+ '500px',
+ 'amazon',
+ 'calendar-plus-o',
+ 'calendar-minus-o',
+ 'calendar-times-o',
+ 'calendar-check-o',
+ 'industry',
+ 'map-pin',
+ 'map-signs',
+ 'map-o',
+ 'map',
+ 'commenting',
+ 'commenting-o',
+ 'houzz',
+ 'vimeo',
+ 'black-tie',
+ 'fonticons',
+ 'reddit-alien',
+ 'edge',
+ 'credit-card-alt',
+ 'codiepie',
+ 'modx',
+ 'fort-awesome',
+ 'usb',
+ 'product-hunt',
+ 'mixcloud',
+ 'scribd',
+ 'pause-circle',
+ 'pause-circle-o',
+ 'stop-circle',
+ 'stop-circle-o',
+ 'shopping-bag',
+ 'shopping-basket',
+ 'hashtag',
+ 'bluetooth',
+ 'bluetooth-b',
+ 'percent')
